@@ -863,6 +863,14 @@ failed to upload.</source>
         <source>Failed to get upload link information for file &quot;%1&quot;</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Do you really want to delete file &quot;%1&quot;?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Do you really want to delete folder &quot;%1&quot;?</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -1089,14 +1097,6 @@ failed to upload.</source>
         <source>&amp;Generate %1 Upload Link</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Are you sure you want to delete &quot;%1&quot; ?</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Are you sure you want to delete those files ?</source>
-        <translation type="unfinished"/>
-    </message>
 </context>
 <context>
     <name>FinderSyncHost</name>
@@ -1586,6 +1586,10 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Do you want to delete files in library &quot;%1&quot; ?</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Failed to download file %1. Please check disk space or folder permissions</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrivateShareDialog</name>
@@ -2244,6 +2248,14 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Too many files in library</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Failed to download file. Please check disk space or folder permissions</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to upload file blocks. Please check network or firewall</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
