@@ -388,7 +388,7 @@ void SeafileRpcClient::getSyncStatus(LocalRepo &repo)
     int err = SYNC_ERROR_ID_NO_ERROR;
     g_object_get(task, "state", &state, "error", &err, NULL);
 
-    repo.setSyncInfo(state, err);
+    repo.setSyncInfo(state);
 
     if (repo.sync_state == LocalRepo::SYNC_STATE_ING) {
         getRepoTransferInfo(repo.id, &repo.transfer_rate, &repo.transfer_percentage, &repo.rt_state);
