@@ -12,10 +12,6 @@
 #include "api/requests.h"
 #include "settings-dialog.h"
 
-#ifdef HAVE_SPARKLE_SUPPORT
-#include "auto-update-service.h"
-#endif
-
 namespace {
 
 const char *kSettingsGroupForSettingsDialog = "SettingsDialog";
@@ -37,12 +33,6 @@ SettingsDialog::SettingsDialog(QWidget *parent) : QDialog(parent)
 
     mTabWidget->setCurrentIndex(0);
 
-#ifdef HAVE_SPARKLE_SUPPORT
-    if (!AutoUpdateService::instance()->shouldSupportAutoUpdate()) {
-        mCheckLatestVersionBox->setVisible(false);
-    }
-#endif
-
     mLanguageComboBox->addItems(I18NHelper::getInstance()->getLanguages());
     // The range of mProxyPort is set to (0, 65535) in the ui file, so we
     // don't bother with that here.
@@ -99,13 +89,6 @@ void SettingsDialog::updateSettings()
 
     updateProxySettings();
 
-#ifdef HAVE_SPARKLE_SUPPORT
-    if (AutoUpdateService::instance()->shouldSupportAutoUpdate()) {
-        bool enabled = mCheckLatestVersionBox->checkState() == Qt::Checked;
-        AutoUpdateService::instance()->setAutoUpdateEnabled(enabled);
-    }
-#endif
-
     bool language_changed = false;
     if (mLanguageComboBox->currentIndex() != I18NHelper::getInstance()->preferredLanguage()) {
         language_changed = true;
@@ -200,13 +183,6 @@ void SettingsDialog::showEvent(QShowEvent *event)
     ratio = mgr->maxUploadRatio();
     mUploadSpinBox->setValue(ratio);
 
-#ifdef HAVE_SPARKLE_SUPPORT
-    if (AutoUpdateService::instance()->shouldSupportAutoUpdate()) {
-        state = AutoUpdateService::instance()->autoUpdateEnabled() ? Qt::Checked : Qt::Unchecked;
-        mCheckLatestVersionBox->setCheckState(state);
-    }
-#endif
-
     mDeleteConfirmSpinBox->setValue(mgr->deleteConfirmThreshold());
 
     SettingsManager::SeafileProxy proxy = mgr->getProxy();
